/*********************************************************************
* Program: FILES.H - header for FILES.C
* Author: Philip J. Erdelsky
* Compiler: Turbo C 2.0
* Memory Models: any
* Date: April 1990  May be used freely if authorship is acknowledged.
*********************************************************************/

/* modes for open() */

#define O_RDONLY  0x01  /* open for reading only        */
#define O_WRONLY  0x02  /* open for writing only        */
#define O_RDWR    0x03  /* open for reading and writing */

/* options to be OR'ed with O_WRONLY */

#define O_CREAT   0x04  /* create file if it does not exist */
#define O_TRUNC   0x08  /* truncate file if it does exist   */

/* option to be OR'ed with O_WRONLY|O_CREAT */

#define O_EXCL    0x10  /* fail operation if file exists */

/* modes for lseek() */

#define SEEK_SET  0  /* relative to beginning of file */
#define SEEK_CUR  1  /* relative to current position  */
#define SEEK_END  2  /* relative to end of file       */

/* file error codes  */

#define DIRECTORY_FULL           (-1)
#define FILE_NOT_FOUND           (-2)
#define LSEEK_MODE_ERROR         (-3)
#define FILE_MODE_ERROR          (-4)
#define FILE_FORMAT_ERROR        (-5)
#define TOO_MANY_FILES           (-6)
#define FILE_ALREADY_EXISTS      (-7)
#define WRITE_ACCESS_DENIED      (-8)
#define INVALID_DRIVE_SPEC       (-9)
#define INVALID_FILE_NAME        (-10)
#define INVALID_HANDLE           (-11)
#define INVALID_LSEEK_OFFSET     (-12)
#define MULTIPLE_WRITE           (-13)
#define VOLUME_OR_DIRECTORY_NAME (-14)

#ifdef TURBOC
/*
 * redefine the low level subroutines so that they don't conflict
 * with those provided by Turbo C
 */
#define open  Xopen
#define read  Xread
#define write Xwrite
#define close Xclose
#define lseek Xlseek
#endif

/* function prototypes */

extern int open(char *, int);
extern int read(int, char *, int);
extern int write(int, char *, int);
extern int close(int);
extern long lseek(int, long, int);
