// LISTING 1 -- LIFO.HPP
// Last-in, first-out, stack-like singly-linked list.
// (c) 1990 C Gazette -- Use freely if authorship acknowledged

#ifndef _LIFO_HPP_
#define _LIFO_HPP_
// A "virtual node."  Notice it doesn't hold any data; this must
// be added by inheritance:
struct node {
  node * next;                   // link to next node in list.
  node(node * nx) : next(nx) {}  // very simple constructor
  virtual ~node() {} // so lifo can properly destroy what it holds
};

struct lifo {
  node *head, *cursor;  // head always points to the top of the list
  // initialize an empty list:
  lifo() : head(NULL), cursor(NULL) {}
  // top() and next() return the current node or NULL, for the list's end:
  node * top() { return cursor = head; }  // go to the top of the list
  node * next() {  // Only move forward if cursor isn't NULL:
    if(cursor) cursor = cursor->next;
    return cursor;
  }

  // Paste a new node in at the top (this is tricky):
  void push() { head = new node(head); }

  // Remove the node at the top of the list (the last push):
  int pop() {
    // move to the top and make sure something is in the list:
    if(!top()) return 0;  // return 0 for empty list
    head = head->next;    // may be NULL
    delete cursor;        // remove top element
    cursor = head;        // move cursor forward to new top of list
    return (int) cursor;  // non-zero value means non-empty list
  }
  ~lifo() {
    while(pop()) // remove elements until the list is empty
      ;
  }
};
#endif // _LIFO_HPP_